@@ -672,7 +672,10 @@ def add_annotations_to_class_dict(cls_dict, previous_frame):
             first_arg = getattr(v, "__args__", [0])[0]
             mros = getattr(first_arg, "__mro__", getattr(v, "__mro__", []))
             if not type_is_generic(v) and (
-                isinstance(v, (Field, Structure)) or Field in mros or Structure in mros or is_function_returning_field(v)
+                isinstance(v, (Field, Structure))
+                or Field in mros
+                or Structure in mros
+                or is_function_returning_field(v)
             ):
                 if k in cls_dict:
                     defaults[k] = cls_dict[k]
@@ -715,7 +718,6 @@ def convert_field_type_if_possible(the_field):
         return get_typing_lib_info(the_field)
 
 
-
 class Structure(UniqueMixin, metaclass=StructMeta):
     """
     The base class to support strictly defined structures. When creating a new instance of
@@ -985,6 +987,15 @@ class Structure(UniqueMixin, metaclass=StructMeta):
             v is not None for k, v in self.__dict__.items() if k not in internal_props
         )
 
+    def _additional_serialization(self) -> dict:
+        """
+        :return: additional fields when serializing a structure,
+            Each key is a key in the output json, and each value
+            can either be a function with no parameters, a method, or a
+            simple value
+        """
+        return {}
+
     @classmethod
     def get_all_fields_by_name(cls):
         return _get_all_fields_by_name(cls)
@@ -1269,8 +1280,6 @@ class Structure(UniqueMixin, metaclass=StructMeta):
             x for x in getattr(cls, REQUIRED_FIELDS) if x in fields_to_pick
         ]
 
-
-
         classname = class_name if class_name else f"Pick{cls.__name__}"
         newclass = type(classname, (Structure,), cls_dict)
 
